aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/python
diff options
context:
space:
mode:
Diffstat (limited to 'resources/libraries/python')
-rw-r--r--resources/libraries/python/ContainerUtils.py3
-rw-r--r--resources/libraries/python/VppConfigGenerator.py8
2 files changed, 7 insertions, 4 deletions
diff --git a/resources/libraries/python/ContainerUtils.py b/resources/libraries/python/ContainerUtils.py
index aafc3eb180..da3d7057dc 100644
--- a/resources/libraries/python/ContainerUtils.py
+++ b/resources/libraries/python/ContainerUtils.py
@@ -327,7 +327,8 @@ class ContainerEngine(object):
if cpuset_cpus:
corelist_workers = ','.join(str(cpu) for cpu in cpuset_cpus)
vpp_config.add_cpu_corelist_workers(corelist_workers)
- vpp_config.add_plugin_disable('dpdk_plugin.so')
+ vpp_config.add_plugin('disable', 'default')
+ vpp_config.add_plugin('enable', 'memif_plugin.so')
self.execute('mkdir -p /etc/vpp/')
self.execute('echo "{c}" | tee {f}'
diff --git a/resources/libraries/python/VppConfigGenerator.py b/resources/libraries/python/VppConfigGenerator.py
index 819224f485..4476cfa3ee 100644
--- a/resources/libraries/python/VppConfigGenerator.py
+++ b/resources/libraries/python/VppConfigGenerator.py
@@ -358,14 +358,16 @@ class VppConfigGenerator(object):
path = ['ip', 'heap-size']
self.add_config_item(self._nodeconfig, value, path)
- def add_plugin_disable(self, *plugins):
- """Add plugin disable for specific plugin.
+ def add_plugin(self, state, *plugins):
+ """Add plugin section for specific plugin(s).
+ :param state: State of plugin [enable|disable].
:param plugins: Plugin(s) to disable.
+ :type state: str
:type plugins: list
"""
for plugin in plugins:
- path = ['plugins', 'plugin {0}'.format(plugin), 'disable']
+ path = ['plugins', 'plugin {0}'.format(plugin), state]
self.add_config_item(self._nodeconfig, ' ', path)
def add_dpdk_no_multi_seg(self):